# first, set the working directory

.libPaths("~/local/R_libs/")
library(Rcpp)
library(delimitR)
# next, define the parameters
obstree <- c('((0,1),2);') # a guide tree
obsspecies<- 3 # the number of species
obssamplesize <- rep(20,3) # the sample sizes for each species
obsloci <- 1 ## per linkage block (I use unlinked, so it's 1)
obssnps <- 1000 # the number of SNPs
obspopsizeprior <- list(c(10000,100000),c(10000,100000),c(10000,100000))
obsdivtimeprior <- list(c(5000,10000),c(50000,100000))
obsmigrateprior <- list(c(0.000005,0.00005))
obsprefix <- 'simulationstudy1000snps' #prefix2
obsnreps <- 5000
obsnclasses <- 10
obspathtofsc <- "./fsc26"
obsmaxinterval <- 1
traitfile <- 'dwgsimulationstudy_traits.txt'
migmatrix <- matrix(c(F, T, F,
                      T, F, F,
                      F, F, F), nrow = 3, ncol =3)
dwg = F
sc = T

# now, set up the models
setup_fsc2(tree=obstree,samplesizes=obssamplesize,nspec=obsspecies,prefix=obsprefix,migrateprior=obsmigrateprior,divtimeprior=obsdivtimeprior,
           popsizeprior=obspopsizeprior,nsnps=obssnps, secondarycontact = sc, divwgeneflow = dwg, maxmigrations = 1, migmatrix = migmatrix)




fastsimcoalsims(prefix=obsprefix,pathtofsc=obspathtofsc,nreps=obsnreps)

FullPrior <- makeprior(prefix=obsprefix,nspec=obsspecies,nclasses=obsnclasses,getwd(),traitsfile = traitfile,threshold=100, thefolder = "Prior",ncores=4)

clean_working(prefix=obsprefix)


# now, generate the pseudoobserved data
obsnreps <- 1000
obsprefix <- 'pseudoobserved1000snps_' #prefix2
setup_fsc2(tree=obstree,samplesizes=obssamplesize,nspec=obsspecies,prefix=obsprefix,migrateprior=obsmigrateprior,divtimeprior=obsdivtimeprior,
           popsizeprior=obspopsizeprior,nsnps=obssnps, secondarycontact = sc, divwgeneflow = dwg, maxmigrations = 1, migmatrix = migmatrix)

fastsimcoalsims(prefix=obsprefix,pathtofsc=obspathtofsc,nreps=obsnreps)
Pseudoobserved <- makeprior(prefix=obsprefix,nspec=obsspecies,nclasses=obsnclasses,getwd(),traitsfile = traitfile,threshold=100, thefolder = "Pseudoobserved",ncores=5)
#Pseudoobserved_M1 <- prepobserved("pseudoobserved1000snps_1_MSFS",FullPrior, ReducedPrior, obsnclasses, obsspecies, traitfile, 100)

# now build the RF

ReducedPrior <- Prior_reduced(FullPrior)
Models <- as.factor(FullPrior[,'Model'])
myRF <- RF_build_abcrf(ReducedPrior,FullPrior,500)
myRF

# now get the psuedoobserved data ready
names(Pseudoobserved) <- names(FullPrior)

# get rid of columns that aren't in the prior
tokeep <- as.vector(names(ReducedPrior))
Pseudoobserved_reduced <- subset(Pseudoobserved, select = c(tokeep))

# now, we can run the RF predict function
prediction <- RF_predict_abcrf(RF=myRF, Observed_Reduced = Pseudoobserved_reduced,ReducedPrior = ReducedPrior, FullPrior=FullPrior, ntrees=500)
summary(prediction)
prediction
